# Changelog

## Version 0.1.0

*Release date*: 2024/03/01

**First release of *Burocrata*, a tool for checking and adding license and
copyright notices to source code files.**

This is a command-line program and has the basic implementation working. It's
still a prototype and needs to be tested in the wild. It also has no unit tests
at the moment.
